@@ -24,15 +24,20 @@
 #include <QString>
 #include <QStringList>
 
+#include "bugzillaintegration/libbugzilla/clients/productclient.h"
+
 class Product;
 class BugzillaManager;
 class CrashedApplication;
 
+/**
+ * Maps our crashed entity to a bugzilla product/component/version.
+ */
 class ProductMapping: public QObject
 {
 Q_OBJECT
 public:
-    explicit ProductMapping(const CrashedApplication *, BugzillaManager *, QObject * parent = nullptr);
+    explicit ProductMapping(const CrashedApplication *, BugzillaManager *, QObject *parent = nullptr);
 
     QString bugzillaProduct() const;
     QString bugzillaComponent() const;
@@ -43,7 +48,7 @@ public:
     bool bugzillaVersionDisabled() const;
 
 private Q_SLOTS:
-    void checkProductInfo(const Product &);
+    void checkProductInfo(const Bugzilla::Product::Ptr);
 
 private:
     void map(const QString&);
@@ -51,17 +56,16 @@ private:
     void getRelatedProductsUsingInternalFile(const QString&);
 
     QStringList m_relatedBugzillaProducts;
-    QString     m_bugzillaProduct;
-    QString     m_bugzillaComponent;
+    QString m_bugzillaProduct;
+    QString m_bugzillaComponent;
 
-    QString     m_bugzillaVersionString;
+    QString m_bugzillaVersionString;
 
-    const CrashedApplication *   m_crashedAppPtr;
-    BugzillaManager *   m_bugzillaManagerPtr = nullptr;
+    const CrashedApplication *m_crashedAppPtr = nullptr;
+    BugzillaManager *m_bugzillaManagerPtr = nullptr;
 
     bool m_bugzillaProductDisabled;
     bool m_bugzillaVersionDisabled;
-
 };
 
 #endif
