@@ -46,7 +46,6 @@
 #include <QTextStream>
 #include <QTimerEvent>
 #include <QTemporaryFile>
-#include <QDebug>
 #include <QFileDialog>
 
 #include <KMessageBox>
@@ -54,10 +53,13 @@
 #include <KLocalizedString>
 #include <KJobWidgets>
 #include <kio/filecopyjob.h>
+#include <QApplication>
 
 #include "systeminformation.h"
 #include "crashedapplication.h"
 #include "drkonqibackends.h"
+#include "debuggermanager.h"
+#include "backtracegenerator.h"
 
 DrKonqi::DrKonqi()
     : m_signal(0)
@@ -81,11 +83,8 @@ DrKonqi::~DrKonqi()
 //static
 DrKonqi *DrKonqi::instance()
 {
-    static DrKonqi *drKonqiInstance = nullptr;
-    if (!drKonqiInstance) {
-        drKonqiInstance = new DrKonqi();
-    }
-    return drKonqiInstance;
+    static DrKonqi drKonqiInstance;
+    return &drKonqiInstance;
 }
 
 //based on KCrashDelaySetHandler from kdeui/util/kcrash.cpp
@@ -107,7 +106,6 @@ protected:
 bool DrKonqi::init()
 {
     if (!instance()->m_backend->init()) {
-        cleanup();
         return false;
     } else { //all ok, continue initialization
         // Set drkonqi to handle its own crashes, but only if the crashed app
@@ -123,11 +121,6 @@ bool DrKonqi::init()
     }
 }
 
-void DrKonqi::cleanup()
-{
-    delete instance();
-}
-
 //static
 SystemInformation *DrKonqi::systemInformation()
 {
@@ -172,7 +165,7 @@ void DrKonqi::saveReport(const QString & reportText, QWidget *parent)
         dlg->setWindowTitle(i18nc("@title:window","Select Filename"));
         dlg->setAcceptMode(QFileDialog::AcceptSave);
         dlg->setFileMode(QFileDialog::AnyFile);
-        dlg->setConfirmOverwrite(true);
+        dlg->setOption(QFileDialog::DontResolveSymlinks, false);
         if (dlg->exec() != QDialog::Accepted) {
             return;
         }
@@ -201,7 +194,7 @@ void DrKonqi::saveReport(const QString & reportText, QWidget *parent)
             }
 
             // QFileDialog was run with confirmOverwrite, so we can safely
-            // overwrite as necesssary.
+            // overwrite as necessary.
             KIO::FileCopyJob* job = KIO::file_copy(QUrl::fromLocalFile(tf.fileName()),
                                                    fileUrl,
                                                    -1,
@@ -214,6 +207,68 @@ void DrKonqi::saveReport(const QString & reportText, QWidget *parent)
     }
 }
 
+// Helper functions for the shutdownSaveReport
+class ShutdownHelper : public QObject {
+    Q_OBJECT
+public:
+    QString shutdownSaveString;
+
+    void removeOldFilesIn(QDir &dir)
+    {
+        auto fileList = dir.entryInfoList(QDir::Files | QDir::NoDotAndDotDot,
+                                          QDir::SortFlag::Time | QDir::Reversed);
+        for(int i = fileList.size(); i >= 10; i--) {
+            auto currentFile = fileList.takeFirst();
+            dir.remove(currentFile.fileName());
+        }
+    }
+
+    void saveReportAndQuit()
+    {
+        const QString dirname = QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
+        // Try to create the directory to save the logs, if we can't open the directory,
+        // just bail out. no need to hold the shutdown process.
+        QDir dir(dirname);
+        if (!dir.mkpath(dirname)) {
+            qApp->quit();
+        }
+
+        removeOldFilesIn(dir);
+        const QString defname = dirname
+                        + QLatin1Char('/') 
+                        + QStringLiteral("pid-")
+                        + QString::number(DrKonqi::pid())
+                        + QLatin1Char('-')
+                        + getSuggestedKCrashFilename(DrKonqi::crashedApplication());
+
+        QFile shutdownSaveFile(defname);
+        if (shutdownSaveFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
+            QTextStream ts(&shutdownSaveFile);
+            ts << shutdownSaveString;
+            ts.flush();
+            shutdownSaveFile.close();
+        }
+        deleteLater();
+        qApp->quit();
+    }
+
+    void appendNewLine(const QString& newLine)
+    {
+        shutdownSaveString += newLine;
+    }
+};
+
+void DrKonqi::shutdownSaveReport()
+{
+    auto btGenerator = instance()->debuggerManager()->backtraceGenerator();
+    auto shutdownHelper = new ShutdownHelper();
+    QObject::connect(btGenerator, &BacktraceGenerator::done, shutdownHelper, &ShutdownHelper::saveReportAndQuit);
+    QObject::connect(btGenerator, &BacktraceGenerator::someError, shutdownHelper, &ShutdownHelper::saveReportAndQuit);
+    QObject::connect(btGenerator, &BacktraceGenerator::failedToStart, shutdownHelper, &ShutdownHelper::saveReportAndQuit);
+    QObject::connect(btGenerator, &BacktraceGenerator::newLine, shutdownHelper, &ShutdownHelper::appendNewLine);
+    btGenerator->start();
+}
+
 void DrKonqi::setSignal(int signal)
 {
     instance()->m_signal = signal;
@@ -336,13 +391,18 @@ int DrKonqi::thread()
 
 bool DrKonqi::ignoreQuality()
 {
-    return qEnvironmentVariableIsSet("DRKONQI_IGNORE_QUALITY");
+    static bool ignore = qEnvironmentVariableIsSet("DRKONQI_IGNORE_QUALITY") ||
+            qEnvironmentVariableIsSet("DRKONQI_TEST_MODE");
+    return ignore;
 }
 
 const QString &DrKonqi::kdeBugzillaURL()
 {
-    // NB: for practical reasons this cannot use the shared instance. Initing the instances requires
-    //   knowing the URL already, so we'd have an init loop. Use a local static instead.
+    // WARNING: for practical reasons this cannot use the shared instance
+    //   Initing the instances requires knowing the URL already, so we'd have
+    //   an init loop. Use a local static instead. Otherwise we'd crash on
+    //   initialization of global statics derived from our return value.
+    //   Always copy into the local static and return that!
     static QString url;
     if (!url.isEmpty()) {
         return url;
@@ -353,6 +413,13 @@ const QString &DrKonqi::kdeBugzillaURL()
         return url;
     }
 
-    url = QStringLiteral("https://bugs.kde.org/");
+    if (qEnvironmentVariableIsSet("DRKONQI_TEST_MODE")) {
+        url = QStringLiteral("https://bugstest.kde.org/");
+    } else {
+        url = QStringLiteral("https://bugs.kde.org/");
+    }
+
     return url;
 }
+
+#include "drkonqi.moc"
