@@ -31,9 +31,17 @@
 #include <QIcon>
 
 #include <KAboutData>
+#include <KConfigGroup>
 #include <KLocalizedString>
+#include <KSharedConfig>
 #include <QCommandLineParser>
 #include <QDebug>
+#include <QTemporaryFile>
+#include <QFile>
+
+#include <QDBusConnection>
+#include <QDBusInterface>
+#include <QDBusReply>
 
 #include <config-drkonqi.h>
 #if HAVE_X11
@@ -47,11 +55,49 @@
 #include "drkonqi.h"
 #include "drkonqidialog.h"
 #include "statusnotifier.h"
+#include "debuggermanager.h"
+#include "backtracegenerator.h"
 
 static const char version[] = PROJECT_VERSION;
 static const char description[] = I18N_NOOP("The KDE Crash Handler gives the user feedback "
                                             "if a program has crashed.");
 
+namespace {
+    void openDrKonqiDialog () {
+        DrKonqiDialog *w = new DrKonqiDialog();
+        QObject::connect(w, &DrKonqiDialog::rejected, qApp, &QApplication::quit);
+        w->show();
+    #ifdef Q_OS_MACOS
+        KWindowSystem::forceActiveWindow(w->winId());
+    #endif
+    }
+
+    void requestDrKonqiDialog(bool restarted, bool interactionAllowed) {
+        StatusNotifier *statusNotifier = new StatusNotifier();
+        statusNotifier->setActivationAllowed(interactionAllowed);
+        if (interactionAllowed) {
+            statusNotifier->show();
+        }
+        if (!restarted) {
+            statusNotifier->notify();
+        }
+        QObject::connect(statusNotifier, &StatusNotifier::expired, qApp, &QApplication::quit);
+        QObject::connect(statusNotifier, &StatusNotifier::activated, &openDrKonqiDialog);
+    }
+
+    bool isShuttingDown() {
+        if (QDBusConnection::sessionBus().isConnected()) {
+            QDBusInterface remoteApp( QStringLiteral("org.kde.ksmserver"),
+                                      QStringLiteral("/KSMServer"),
+                                      QStringLiteral("org.kde.KSMServerInterface" ));
+
+            QDBusReply<bool> reply = remoteApp.call( QStringLiteral("isShuttingDown") );
+            return reply.isValid() ? reply.value() : false;
+        }
+        return false;
+    }
+}
+
 int main(int argc, char* argv[])
 {
 #ifndef Q_OS_WIN //krazy:exclude=cpp
@@ -62,8 +108,8 @@ int main(int argc, char* argv[])
     }
 #endif
 
-    QApplication qa(argc, argv);
-    qa.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QApplication app(argc, argv);
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     KLocalizedString::setApplicationDomain("drkonqi5");
 
     // Prevent KApplication from setting the crash handler. We will set it later...
@@ -84,41 +130,43 @@ int main(int argc, char* argv[])
     aboutData.addAuthor(i18nc("@info:credit","A. L. Spehr"), QString(),
                          QStringLiteral("spehr@kde.org"));
     KAboutData::setApplicationData(aboutData);
-    qa.setWindowIcon(QIcon::fromTheme(QStringLiteral("tools-report-bug"), qa.windowIcon()));
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("tools-report-bug"), app.windowIcon()));
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
 
-    QCommandLineOption signalOption(QStringLiteral("signal"), i18nc("@info:shell","The signal <number> that was caught"), QStringLiteral("number"));
-    QCommandLineOption appNameOption(QStringLiteral("appname"), i18nc("@info:shell","<Name> of the program"), QStringLiteral("name"));
-    QCommandLineOption appPathOption(QStringLiteral("apppath"), i18nc("@info:shell","<Path> to the executable"), QStringLiteral("path"));
-    QCommandLineOption appVersionOption(QStringLiteral("appversion"), i18nc("@info:shell","The <version> of the program"), QStringLiteral("version"));
-    QCommandLineOption bugAddressOption(QStringLiteral("bugaddress"), i18nc("@info:shell","The bug <address> to use"), QStringLiteral("address"));
-    QCommandLineOption programNameOption(QStringLiteral("programname"), i18nc("@info:shell","Translated <name> of the program"), QStringLiteral("name"));
-    QCommandLineOption pidOption(QStringLiteral("pid"), i18nc("@info:shell","The <PID> of the program"), QStringLiteral("pid"));
-    QCommandLineOption startupIdOption(QStringLiteral("startupid"), i18nc("@info:shell","Startup <ID> of the program"), QStringLiteral("id"));
-    QCommandLineOption kdeinitOption(QStringLiteral("kdeinit"), i18nc("@info:shell","The program was started by kdeinit"));
-    QCommandLineOption saferOption(QStringLiteral("safer"), i18nc("@info:shell","Disable arbitrary disk access"));
-    QCommandLineOption restartedOption(QStringLiteral("restarted"), i18nc("@info:shell","The program has already been restarted"));
-    QCommandLineOption keepRunningOption(QStringLiteral("keeprunning"), i18nc("@info:shell","Keep the program running and generate "
+    const QCommandLineOption signalOption(QStringLiteral("signal"), i18nc("@info:shell","The signal <number> that was caught"), QStringLiteral("number"));
+    const QCommandLineOption appNameOption(QStringLiteral("appname"), i18nc("@info:shell","<Name> of the program"), QStringLiteral("name"));
+    const QCommandLineOption appPathOption(QStringLiteral("apppath"), i18nc("@info:shell","<Path> to the executable"), QStringLiteral("path"));
+    const QCommandLineOption appVersionOption(QStringLiteral("appversion"), i18nc("@info:shell","The <version> of the program"), QStringLiteral("version"));
+    const QCommandLineOption bugAddressOption(QStringLiteral("bugaddress"), i18nc("@info:shell","The bug <address> to use"), QStringLiteral("address"));
+    const QCommandLineOption programNameOption(QStringLiteral("programname"), i18nc("@info:shell","Translated <name> of the program"), QStringLiteral("name"));
+    const QCommandLineOption pidOption(QStringLiteral("pid"), i18nc("@info:shell","The <PID> of the program"), QStringLiteral("pid"));
+    const QCommandLineOption startupIdOption(QStringLiteral("startupid"), i18nc("@info:shell","Startup <ID> of the program"), QStringLiteral("id"));
+    const QCommandLineOption kdeinitOption(QStringLiteral("kdeinit"), i18nc("@info:shell","The program was started by kdeinit"));
+    const QCommandLineOption saferOption(QStringLiteral("safer"), i18nc("@info:shell","Disable arbitrary disk access"));
+    const QCommandLineOption restartedOption(QStringLiteral("restarted"), i18nc("@info:shell","The program has already been restarted"));
+    const QCommandLineOption keepRunningOption(QStringLiteral("keeprunning"), i18nc("@info:shell","Keep the program running and generate "
                                                     "the backtrace at startup"));
-    QCommandLineOption threadOption(QStringLiteral("thread"), i18nc("@info:shell","The <thread id> of the failing thread"), QStringLiteral("threadid"));
-    QCommandLineOption dialogOption(QStringLiteral("dialog"), i18nc("@info:shell","Do not show a notification but launch the debug dialog directly"));
+    const QCommandLineOption threadOption(QStringLiteral("thread"), i18nc("@info:shell","The <thread id> of the failing thread"), QStringLiteral("threadid"));
+    const QCommandLineOption dialogOption(QStringLiteral("dialog"), i18nc("@info:shell","Do not show a notification but launch the debug dialog directly"));
 
-    parser.addOption(signalOption);
-    parser.addOption(appNameOption);
-    parser.addOption(appPathOption);
-    parser.addOption(appVersionOption);
-    parser.addOption(bugAddressOption);
-    parser.addOption(programNameOption);
-    parser.addOption(pidOption);
-    parser.addOption(startupIdOption);
-    parser.addOption(kdeinitOption);
-    parser.addOption(saferOption);
-    parser.addOption(restartedOption);
-    parser.addOption(keepRunningOption);
-    parser.addOption(threadOption);
-    parser.addOption(dialogOption);
+    parser.addOptions({
+        signalOption,
+        appNameOption,
+        appPathOption,
+        appVersionOption,
+        bugAddressOption,
+        programNameOption,
+        pidOption,
+        startupIdOption,
+        kdeinitOption,
+        saferOption,
+        restartedOption,
+        keepRunningOption,
+        threadOption,
+        dialogOption
+    });
 
     // Add all unknown options but make sure to print a warning.
     // This enables older DrKonqi's to run by newer KCrash instances with
@@ -131,14 +179,14 @@ int main(int argc, char* argv[])
     // them again once we have injected no-op options for all unknown ones.
     // This allows ::process to still do common argument handling for --version
     // as well as standard error handling.
-    if (!parser.parse(qa.arguments())) {
+    if (!parser.parse(app.arguments())) {
         for (const QString &option : parser.unknownOptionNames()) {
             qWarning() << "Unknown option" << option << " - ignoring it.";
             parser.addOption(QCommandLineOption(option));
         }
     }
 
-    parser.process(qa);
+    parser.process(app);
     aboutData.processCommandLine(&parser);
 
     DrKonqi::setSignal(parser.value(signalOption).toInt());
@@ -166,35 +214,29 @@ int main(int argc, char* argv[])
         return 1;
     }
 
-    qa.setQuitOnLastWindowClosed(false);
+    app.setQuitOnLastWindowClosed(false);
 
-    auto openDrKonqiDialog = [&qa]{
-        DrKonqiDialog *w = new DrKonqiDialog();
-        QObject::connect(w, &DrKonqiDialog::rejected, &qa, &QApplication::quit);
-        w->show();
-#ifdef Q_OS_MACOS
-        KWindowSystem::forceActiveWindow(w->winId());
-#endif
-    };
+    const bool restarted = parser.isSet(restartedOption);
 
-    bool restarted = parser.isSet(restartedOption);
+    // Whether the user should be encouraged to file a bug report
+    const bool interactionAllowed = KConfigGroup(KSharedConfig::openConfig(), "General").readEntry("InteractionAllowed", true);
+    const bool shuttingDown = isShuttingDown();
+
+    // For automatically restarted services or during shutdown, do nothing in case no interaction is allowed
+    if (!forceDialog && !interactionAllowed && (restarted || shuttingDown)) {
+        return 0;
+    }
 
     // if no notification service is running (eg. shell crashed, or other desktop environment)
     // and we didn't auto-restart the app, open DrKonqi dialog instead of showing an SNI
-    // and emitting a desktop notification
-    if (forceDialog || (!restarted && !StatusNotifier::notificationServiceRegistered())) {
+    // and emitting a desktop notification.
+    if (shuttingDown) {
+        DrKonqi::shutdownSaveReport();
+    } else if (forceDialog || (!restarted && !StatusNotifier::notificationServiceRegistered())) {
         openDrKonqiDialog();
     } else {
-        StatusNotifier *statusNotifier = new StatusNotifier();
-        if (!restarted) {
-            statusNotifier->notify();
-        }
-        QObject::connect(statusNotifier, &StatusNotifier::expired, &qa, &QApplication::quit);
-        QObject::connect(statusNotifier, &StatusNotifier::activated, openDrKonqiDialog);
+        requestDrKonqiDialog(restarted, interactionAllowed);
     }
 
-    int ret = qa.exec();
-
-    DrKonqi::cleanup();
-    return ret;
+    return app.exec();
 }
